"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = waitFor;
exports.waitForElement = waitForElement;

var _errors = require("./helpers/errors");

const DEFAULT_TIMEOUT = 4500;
const DEFAULT_INTERVAL = 50;

function waitFor(expectation, options) {
  var _options$timeout, _options$interval;

  const timeout = (_options$timeout = options === null || options === void 0 ? void 0 : options.timeout) !== null && _options$timeout !== void 0 ? _options$timeout : DEFAULT_TIMEOUT;
  const interval = (_options$interval = options === null || options === void 0 ? void 0 : options.interval) !== null && _options$interval !== void 0 ? _options$interval : DEFAULT_INTERVAL;
  const startTime = Date.now();
  return new Promise((resolve, reject) => {
    const rejectOrRerun = error => {
      if (Date.now() - startTime >= timeout) {
        reject(error);
        return;
      }

      setTimeout(runExpectation, interval);
    };

    function runExpectation() {
      try {
        const result = expectation();
        resolve(result);
      } catch (error) {
        rejectOrRerun(error);
      }
    }

    setTimeout(runExpectation, 0);
  });
}

function waitForElement(expectation, _timeout = 4500, _interval = 50) {
  (0, _errors.throwRemovedFunctionError)('waitForElement', 'migration-v2#waitfor-api-changes');
  return Promise.reject();
}